clear all
cd "XXX"
use JPR_19_350_ReplicationData.dta 

lab var usatt "Attitudes towards the U.S."
lab var USYPGtreat "YPG Treatment"
lab var rusatt "Attitudes towards Russia"
lab var RUSTurkmentreat "Turkmen Treatment"
lab var turk "Turk"
lab var turkusypg "Turk (YPG Treatment=1)"
lab var kurd "Kurd"
lab var kurdusypg "Kurd (YPG Treatment=1)"
lab var kurdrusturkmen "Kurd (Turkmen Treatment=1)"
lab var turkrusturkmen "Turk (Turkmen Treatment=1)"
lab var age "Age"
lab var male "Male"
lab var education "Education"
lab var income "Income"
lab var urban "Urban"
lab var religiosity "Religiosity"
lab var akpvoteNOW "Incumbent Party Support"

***MainModels_Heterogenous Treatment Effects
eststo m1:regress usatt USYPGtreat turk  turkusypg, robust
eststo m2:regress usatt USYPGtreat turk turkusypg age male education income urban religiosity akpvoteNOW, robust
eststo m3:regress usatt USYPGtreat kurd kurdusypg, robust
eststo m4:regress usatt USYPGtreat kurd kurdusypg age male education income urban religiosity akpvoteNOW, robust
eststo m5:regress rusatt RUSTurkmentreat turk turkrusturkmen, robust
eststo m6:regress rusatt RUSTurkmentreat turk turkrusturkmen age male education income urban religiosity akpvoteNOW, robust
eststo m7:regress rusatt RUSTurkmentreat kurd kurdrusturkmen, robust
eststo m8:regress rusatt RUSTurkmentreat kurd kurdrusturkmen age male education income urban religiosity akpvoteNOW, robust
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "ExperimentsAllRR.tex", tex replace b(%10.3f) se scalars("r2 \$R^2\$") label starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant)

***Main Model - Only in Diyarbakir 
eststo m1:regress usatt USYPGtreat kurd kurdusypg if diyarbakir==1, robust
eststo m2:regress usatt USYPGtreat kurd kurdusypg age male education income urban religiosity akpvoteNOW if diyarbakir==1, robust
eststo m3:regress rusatt RUSTurkmentreat kurd kurdrusturkmen if diyarbakir==1, robust
eststo m4:regress rusatt RUSTurkmentreat kurd kurdrusturkmen age male education income urban religiosity akpvoteNOW if diyarbakir==1, robust
esttab m1 m2 m3 m4 using "DiyarbakirKurtModelRR.tex", tex replace b(%10.3f) se scalars("r2 \$R^2\$") label starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant)


coefplot m2 || m4 || m8 || m6, drop(USYPGtreat turk kurd RUSTurkmentreat age male education income urban religiosity _cons) xline(0) byopts(row(1)) coeflabel(turkusypg="Turk (YPG Treatment=1)" kurdusypg="Kurd (YPG Treatment=1)" kurdrusturkmen="Kurd (Turkmen Treatment=1)" turkrusturkmen="Turk (Turkment Treatment=1)") xlabel(-2 -1 0 1 2)


***Graph1/Exp1 - Saturated Regression for unbiased results // McCarthan Humpreys' slides
clear all
set obs 1
gen turk=1
gen USYPGtreat=0
gen turkusypg=turk*USYPGtreat
save outofsample1.dta, replace
use "/Users/efetokdemir/Desktop/Turkey2016-2017Data/turkiye anket.dta"
regress usatt USYPGtreat turk turkusypg if usatttreat!=2, robust
use outofsample1.dta, clear
predict turknotreatxb, xb
predict turknotreatsd, stdp
drop USYPGtreat turkusypg
gen USYPGtreat=1
gen turkusypg=turk*USYPGtreat
predict turktreatxb, xb
predict turktreatsd, stdp
gen ub0=1.96*turknotreatsd+turknotreatxb
gen lb0=-1.96*turknotreatsd+turknotreatxb
gen ub1=1.96*turktreatsd+turktreatxb
gen lb1=-1.96*turktreatsd+turktreatxb

clear all
set obs 1
gen kurd=1
gen USYPGtreat=0
gen kurdusypg=kurd*USYPGtreat
save outofsample1.dta, replace
use "/Users/efetokdemir/Desktop/Turkey2016-2017Data/turkiye anket.dta"
regress usatt USYPGtreat kurd kurdusypg if usatttreat!=2, robust
use outofsample1.dta, clear
predict kurdnotreatxb, xb
predict kurdnotreatsd, stdp
drop USYPGtreat kurdusypg
gen USYPGtreat=1
gen kurdusypg=kurd*USYPGtreat
predict kurdtreatxb, xb
predict kurdtreatsd, stdp
gen ub0=1.96*kurdnotreatsd+kurdnotreatxb
gen lb0=-1.96*kurdnotreatsd+kurdnotreatxb
gen ub1=1.96*kurdtreatsd+kurdtreatxb
gen lb1=-1.96*kurdtreatsd+kurdtreatxb

***Graph2/Exp2 - Saturated Regression for unbiased results // McCarthan Humpreys' slides
clear all
set obs 1
gen turk=1
gen RUSTurkmentreat=0
gen turkrusturkmen=turk*RUSTurkmentreat
save outofsample1.dta, replace
use "/Users/efetokdemir/Desktop/Turkey2016-2017Data/turkiye anket.dta"
regress rusatt RUSTurkmentreat turk turkrusturkmen if rusatttreat!=1, robust
use outofsample1.dta, clear
predict turknotreatxb, xb
predict turknotreatsd, stdp
drop RUSTurkmentreat turkrusturkmen
gen RUSTurkmentreat=1
gen turkrusturkmen=turk*RUSTurkmentreat
predict turktreatxb, xb
predict turktreatsd, stdp
gen ub0=1.96*turknotreatsd+turknotreatxb
gen lb0=-1.96*turknotreatsd+turknotreatxb
gen ub1=1.96*turktreatsd+turktreatxb
gen lb1=-1.96*turktreatsd+turktreatxb

clear all
set obs 1
gen kurd=1
gen RUSTurkmentreat=0
gen kurdrusturkmen=kurd*RUSTurkmentreat
save outofsample1.dta, replace
use "/Users/efetokdemir/Desktop/Turkey2016-2017Data/turkiye anket.dta"
regress rusatt RUSTurkmentreat kurd kurdrusturkmen if rusatttreat!=1, robust
use outofsample1.dta, clear
predict kurdnotreatxb, xb
predict kurdnotreatsd, stdp
drop RUSTurkmentreat kurdrusturkmen
gen RUSTurkmentreat=1
gen kurdrusturkmen=kurd*RUSTurkmentreat
predict kurdtreatxb, xb
predict kurdtreatsd, stdp
gen ub0=1.96*kurdnotreatsd+kurdnotreatxb
gen lb0=-1.96*kurdnotreatsd+kurdnotreatxb
gen ub1=1.96*kurdtreatsd+kurdtreatxb
gen lb1=-1.96*kurdtreatsd+kurdtreatxb

*Predicted point estimations (treatxb) and CIs (ub/lb) are stored and then drawn separately again in Stata15


***Online Appendix
*Appendix A. Anova Table
sum age income education male urban religiosity turk kurd akpvoteNOW if usatttreat==0
sum age income education male urban religiosity turk kurd akpvoteNOW if usatttreat==1
sum age income education male urban religiosity turk kurd akpvoteNOW if usatttreat==2

sum age income education male urban religiosity turk kurd akpvoteNOW if rusatttreat==0
sum age income education male urban religiosity turk kurd akpvoteNOW if rusatttreat==1
sum age income education male urban religiosity turk kurd akpvoteNOW if rusatttreat==2

oneway usatttreat age 
oneway usatttreat income 
oneway usatttreat education 
oneway usatttreat male
oneway usatttreat urban
oneway usatttreat religiosity
oneway usatttreat turk
oneway usatttreat kurd
oneway usatttreat akpvoteNOW 

oneway rusatttreat age 
oneway rusatttreat income 
oneway rusatttreat education 
oneway rusatttreat male
oneway rusatttreat urban
oneway rusatttreat religiosity
oneway rusatttreat turk
oneway rusatttreat kurd
oneway rusatttreat akpvoteNOW 

*Appendix B Descriptives
keep usatt rusatt USYPGtreat RUSTurkmentreat turk kurd turkusypg kurdusypg kurdrusturkmen turkrusturkmen male age education income urban religiosity akpvoteNOW
sum usatt rusatt USYPGtreat RUSTurkmentreat turk kurd turkusypg kurdusypg kurdrusturkmen turkrusturkmen male age education income urban religiosity akpvoteNOW
outreg2 using Ch2Desc.tex, replace sum(log) title("Summary Statistics") groupvar(usatt rusatt USYPGtreat RUSTurkmentreat turk kurd turkusypg kurdusypg kurdrusturkmen turkrusturkmenshia male age education income urban religiosity)

*Appendix C Average Treatment Effects
bootstrap, reps(100) seed(1): teffects ra (usatt income urban religiosity education age male) (USYPGtreat)
bootstrap, reps(100) seed(1234): teffects ra (usatt) (USYPGtreat) 
bootstrap, reps(100) seed(12): teffects ra (usatt income urban religiosity education age male) (USFSAtreat)
bootstrap, reps(100) seed(12345): teffects ra (usatt) (USFSAtreat) 
bootstrap, reps(100) seed(123): teffects ra (rusatt income urban religiosity education age male) (RUSTurkmentreat)
bootstrap, reps(100) seed(123456): teffects ra (rusatt) (RUSTurkmentreat) 
bootstrap, reps(100) seed(10): teffects ra (usatt income urban religiosity education age male) (RUSSunnitreat)
bootstrap, reps(100) seed(12340): teffects ra (rusatt) (RUSSunnitreat)

*Appendix D Effect of Identity on rUSAttitudes
eststo m1:reg usatt turk if usatttreat==0, robust 
eststo m2:reg usatt turk age male education income urban religiosity akpvoteNOW if usatttreat==0, robust
eststo m3:reg usatt kurd if usatttreat==0, robust
eststo m4:reg usatt kurd age male education income urban religiosity akpvoteNOW if usatttreat==0, robust
eststo m5:reg rusatt turk if rusatttreat==0, robust
eststo m6:reg rusatt turk age male education income urban religiosity akpvoteNOW if rusatttreat==0, robust
eststo m7:reg rusatt kurd if rusatttreat==0, robust
eststo m8:reg rusatt kurd age male education income urban religiosity akpvoteNOW if rusatttreat==0, robust
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "ControlIDeffectRR.tex", tex replace b(%10.3f) se scalars("r2 \$R^2\$") label starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant)

*Appendix E Replication Dropping Sectarian Treatments
eststo m1:regress usatt USYPGtreat turk  turkusypg if usatttreat!=2, robust
eststo m2:regress usatt USYPGtreat turk turkusypg age male education income urban religiosity akpvoteNOW if usatttreat!=2, robust
eststo m3:regress usatt USYPGtreat kurd kurdusypg if usatttreat!=2, robust
eststo m4:regress usatt USYPGtreat kurd kurdusypg age male education income urban religiosity akpvoteNOW if usatttreat!=2, robust
eststo m5:regress rusatt RUSTurkmentreat kurd kurdrusturkmen if rusatttreat!=1, robust
eststo m6:regress rusatt RUSTurkmentreat kurd kurdrusturkmen age male education income urban religiosity akpvoteNOW if rusatttreat!=1, robust
eststo m7:regress rusatt RUSTurkmentreat turk turkrusturkmen if rusatttreat!=1, robust
eststo m8:regress rusatt RUSTurkmentreat turk turkrusturkmen age male education income urban religiosity akpvoteNOW if rusatttreat!=1, robust
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "DropSectarianRR.tex", tex replace b(%10.3f) se scalars("r2 \$R^2\$") label starlevels(+ 0.20 * 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant)

*Appendix F Sunni-Alevi Sectarian Treatment
clear all
cd "/Users/efetokdemir/Desktop/Papers/Tokdemir_Ch2/Data/"
use tranket.dta 
drop if usatttreat==1
eststo m1:regress usatt c.USAttOSOTreat##c.sunni, robust
eststo m2:regress usatt c.USAttOSOTreat##c.sunni age male education income urban religiosity akpvoteNOW, robust
eststo m3:regress usatt c.USAttOSOTreat##c.alevi, robust
eststo m4:regress usatt c.USAttOSOTreat##c.alevi age male education income urban religiosity akpvoteNOW, robust

clear
use tranket.dta 
drop if rusatttreat==2
eststo m5:regress rusatt c.RUSSunnitreat##c.sunni, robust
eststo m6:regress rusatt c.RUSSunnitreat##c.sunni age male education income urban religiosity akpvoteNOW, robust
eststo m7:regress rusatt c.RUSSunnitreat##c.alevi, robust
eststo m8:regress rusatt c.RUSSunnitreat##c.alevi age male education income urban religiosity akpvoteNOW, robust
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "RobustnessSectRR.tex", tex replace b(%10.3f) se scalars("r2 \$R^2\$") label starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant)
clear all

margins, at(RUSSunnitreat=(0 1) sunni=(0 1)) vsquish
marginsplot, x(sunni) recast(line) xlabel(0 1) level(95)
margins, at(USAttOSOTreat=(0 1) alevi=(0 1)) vsquish
marginsplot, x(alevi) recast(line) xlabel(0 1) level(95)
margins, at(RUSSunnitreat=(0 1) alevi=(0 1)) vsquish
marginsplot, x(alevi) recast(line) xlabel(0 1) level(95)

*Appendix G. Contamination
eststo m5:regress rusatt RUSTurkmentreat turk turkrusturkmen i.usatttreat, robust
eststo m6:regress rusatt RUSTurkmentreat turk turkrusturkmen age male education income urban religiosity akpvoteNOW i.usatttreat, robust
eststo m7:regress rusatt RUSTurkmentreat kurd kurdrusturkmen i.usatttreat, robust
eststo m8:regress rusatt RUSTurkmentreat kurd kurdrusturkmen age male education income urban religiosity akpvoteNOW i.usatttreat, robust
eststo m3:regress rusatt RUSTurkmentreat kurd kurdrusturkmen i.usatttreat if diyarbakir==1, robust
eststo m4:regress rusatt RUSTurkmentreat kurd kurdrusturkmen age male education income urban religiosity akpvoteNOW i.usatttreat if diyarbakir==1, robust
esttab m5 m6 m7 m8 m3 m4 using "ContaminationRR.tex", tex replace b(%10.3f) se scalars("r2 \$R^2\$") label starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant)


*Appendix H. Location
eststo m2:regress usatt USYPGtreat turk turkusypg age male education income urban religiosity akpvoteNOW istanbul diyarbakir, robust
eststo m4:regress usatt USYPGtreat kurd kurdusypg age male education income urban religiosity akpvoteNOW istanbul diyarbakir, robust
eststo m6:regress rusatt RUSTurkmentreat kurd kurdrusturkmen age male education income urban religiosity akpvoteNOW istanbul diyarbakir, robust
eststo m8:regress rusatt RUSTurkmentreat turk turkrusturkmen age male education income urban religiosity akpvoteNOW istanbul diyarbakir, robust
esttab m2 m4 m6 m8 using "AppendixCityRR.tex", tex replace b(%10.3f) se scalars("r2 \$R^2\$") label starlevels(* 0.10 ** 0.05 *** 0.01) varlabels(_cons Constant)

***Appendix I.Ethnocentrism
recode b0601 b0602 b0701 b0702 b0801 b0802 (98 99=.)
factor b0601 b0602 b0701 b0702 b0801 b0802 if kurd==1, pcf
rotate, varimax
predict proturk prokurd
gen ethnokurd=prokurd-proturk
factor b0601 b0602 b0701 b0702 b0801 b0802 if turk==1, pcf
rotate, varimax
predict proturk2 prokurd2
gen ethnoturk=proturk2-prokurd2
gen ethnocent= ethnoturk if turk==1
replace ethnocent= ethnokurd if kurd==1

regress usatt c.kurd##c.ethnocent if usatttreat==0, robust
margins, at(ethnocent=(-2.8 2.8) kurd=(0 1)) vsquish
marginsplot, x(kurd) recast(line) xlabel(0 1) level(95) 

regress usatt c.kurd##c.ethnocent if usatttreat==1, robust
margins, at(ethnocent=(-2.8 2.8) kurd=(0 1)) vsquish
marginsplot, x(kurd) recast(line) xlabel(0 1) level(95) 

regress rusatt c.kurd##c.ethnocent if rusatttreat==0, robust
margins, at(ethnocent=(-2.8 2.8) kurd=(0 1)) vsquish
marginsplot, x(kurd) recast(line) xlabel(0 1) level(95) 

regress rusatt c.kurd##c.ethnocent if rusatttreat==2, robust
margins, at(ethnocent=(-2.8 2.8) kurd=(0 1)) vsquish
marginsplot, x(kurd) recast(line) xlabel(0 1) level(95) 

***Appendix J. YPG attitudes
sum ypgatt
sum ypgatt if turk==1
sum ypgatt if kurd==1
regress ypgatt ibn.ypgtreat, noconstant
contrast r.ypgtreat, nowald
regress ypgatt ibn.ypgtreat if turk==1, noconstant
contrast r.ypgtreat, nowald
regress ypgatt ibn.ypgtreat if kurd==1, noconstant
contrast r.ypgtreat, nowald
test i3.ypgtreat=i4.ypgtreat
